import java.util.*;
import java.awt.*;

/**
 * Example6Applet
 *
 * This is a template applet for animation.
 * It illustrates how to use double buffering.
 *
 * @author Arthur van Hoff
 */
public
class Graphics2D extends java.applet.Applet implements Runnable {
    int frame;
    int delay;
    long dt;
    Thread animator;
    
    private GameEngine game;

    Dimension offDimension;
    Image offImage;
    Graphics offGraphics;
    int r, gr, b;
    
    public Graphics2D()
    {
    	super();
    }

    /**
     * Initialize the applet and compute the delay between frames.
     */
    public void init() {

    dt = System.currentTimeMillis();
    
    /*##################################################
     *############## Define Demo Class #################
     *################################################*/
    game = new RotationalGravity();
    r = gr = b = 0;
    
    String str = getParameter("fps");
	int fps = (str != null) ? Integer.parseInt(str) : 60;
	delay = (fps > 0) ? (1000 / fps) : 100;
	
    }

    /**
     * This method is called when the applet becomes visible on
     * the screen. Create a thread and start it.
     */
    public void start() {
    	
	animator = new Thread(this);
	animator.start();
    }

    /**
     * This method is called by the thread that was created in
     * the start method. It does the main animation.
     */
    public void run() {
	// Remember the starting time
	long tm = System.currentTimeMillis();
	while (Thread.currentThread() == animator) {
	    // Display the next frame of animation.
	    repaint();

	    // Delay depending on how far we are behind.
	    try {
		tm += delay;
		Thread.sleep(Math.max(0, tm - System.currentTimeMillis()));
	    } catch (InterruptedException e) {
		break;
	    }

	    // Advance the frame
	    frame++;
	}
    }

    /**
     * This method is called when the applet is no longer
     * visible. Set the animator variable to null so that the
     * thread will exit before displaying the next frame.
     */
    public void stop() {
	animator = null;
	offImage = null;
	offGraphics = null;
    }

    /**
     * Update a frame of animation.
     */
    public void update(Graphics g) {
	Dimension d = size();

	// Create the offscreen graphics context
	if ((offGraphics == null)
	 || (d.width != offDimension.width)
	 || (d.height != offDimension.height)) {
	    offDimension = d;
	    offImage = createImage(d.width, d.height);
	    offGraphics = offImage.getGraphics();
	}

	// Erase the previous image
	offGraphics.setColor(getBackground());
	offGraphics.fillRect(0, 0, d.width, d.height);
	offGraphics.setColor(Color.black);

	// Paint the frame into the image
	paintFrame(offGraphics);

	// Paint the image onto the screen
	g.drawImage(offImage, 0, 0, null);
    }

    /**
     * Paint the previous frame (if any).
     */
    public void paint(Graphics g) {
	if (offImage != null) {
	    g.drawImage(offImage, 0, 0, null);
	}
    }

    /**
     * Paint a frame of animation.
     */
    public void paintFrame(Graphics g) {
    	long t = System.currentTimeMillis();
    	double t2 = (double)(t - dt)/1000;
    	
    	game.act(t2);

		PointMass p;
		ArrayList l = game.getObjects();
		offGraphics.setColor(Color.black);
		for (int i = 0; i < l.size(); i++)
		{
			p = (PointMass)l.get(i);
			offGraphics.fillOval((int)(p.getLoc().getDX()-2),(int)(p.getLoc().getDY()-2),8,8);
		}
		dt = System.currentTimeMillis();
		/*if (b == 255)
		{
			if (gr == 255)
			{
				if (r == 255)
				{
					r = 0;
					b = 0;
					gr = 0;
				} else
					r+= 255;
			} else
				gr+= 255;
		} else
			b+= 255;*/
	}
}
