public class Vector2D
{
	private double i,j;
	
	public Vector2D()
	{
		init(0,0);
	}
	
	public Vector2D(double nI,double nJ)
	{
		init(nI,nJ);
	}
	
	private void init(double nI, double nJ)
	{
		i = nI;
		j = nJ;
	}
	
	public double dot(Vector2D v)
	{
		return (i*v.getI()) + (j*v.getJ());
	}
	
	public Vector2D add(Vector2D v)
	{
		double aI = i + v.getI();
		double aJ = j + v.getJ();
		return new Vector2D(aI,aJ);
	}
	
	public Vector2D subtract(Vector2D v)
	{
		double aI = i - v.getI();
		double aJ = j - v.getJ();
		return new Vector2D(aI,aJ);
	}
	
	public Vector2D scalarMult(double d)
	{
		return new Vector2D(i*d,j*d);
	}
	
	public Vector2D scalarDiv(double d)
	{
		return new Vector2D(i/d,j/d);
	}
	
	public double magnitude()
	{
		return Math.sqrt(Math.pow(i,2) + Math.pow(j,2));
	}
	
	public double angle(Vector2D v)
	{
		double a = dot(v);
		a /= (this.magnitude() + v.magnitude());
		return Math.acos(a);
	}
	
	public void setMag(double d)
	{
		double r = d / magnitude();
		i *= r;
		j *= r;
	}
	
	public Vector2D setAngle(double a)
	{
		double m = magnitude();
		return new Vector2D(m * Math.cos(a), m * Math.sin(a));
	}

	public double getJ()
	{
		return j;
	}
	
	public double getI()
	{
		return i;
	}
	
	public boolean equals(Vector2D v)
	{
		return (i == v.getI() && j == v.getJ());
	}
	
	public void setJ(double d)
	{
		j = d;
	}
	
	public double getAngle()
	{
		double a;
		if (i == 0)
			if (j > 0)
				return 90;
			else if (j < 0)
				return 270;
			else if (j == 0)
				return 0;
		return (Math.atan(j/i))*(180/Math.PI);
	}
	
	public String toString()
	{
		return "<" + i + "," + j + ">";
	}
}